from setuptools import setup

setup(
    name='tesseractpy',
    version='1.0.0',
    description='tesseractpy - Tesseract C# wrapper wrapped in Python',
    author='LUA9',
    maintainer='LUA9',
    packages=['tesseractpy'],
    include_package_data=True,
)